require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Folder
      class FolderAttributes < UU::OS::REST::DTO

        # Code of the folder.
        attr_accessor :code

        # Name of the folder.
        attr_accessor :name

        # Description of the folder.
        attr_accessor :description

        # UESURI of the folder.
        attr_accessor :uri

        # UESURI of the folder's container.
        attr_accessor :location_uri

        # URI of the organizational unit.
        attr_accessor :organizational_unit_uri

        # URI of the company.
        # @deprecated
        attr_accessor :company_uri

        # UESURI of the meta artifact.
        attr_accessor :meta_artifact_uri

        # UESURI of the competent role.
        attr_accessor :competent_role_uri

        # Security level.
        #
        # @see UU::OS::Artifact::SecurityLevel
        attr_accessor :security_level

        # Creation stamp of the folder.
        attr_accessor :creation_stamp

        # Creation time of the folder.
        attr_accessor :creation_time

        # Modification stamp of the folder.
        attr_accessor :modification_stamp

        # Modification time of the folder.
        attr_accessor :modification_time

        # Version of the folder.
        attr_accessor :version

        # URI of the folder's icon. When null is set, the folder uses icon from meta artifact.
        attr_accessor :icon_uri

        # UESURI of the entity type of the folder. Never null.
        attr_accessor :entity_type_uri

        # @deprecated Always returns nil.
        attr_accessor :artifact_type

        attr_accessor :component_content
        
        # @deprecated Always returns nil.
        def artifact_type
          nil
        end

        # @deprecated Input value is ignored, nil is always assumed.
        def artifact_type=(val)
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        # @deprecated
        def company_uri
          attributes[:companyUri]
        end

        # @deprecated
        def company_uri=(val)
          if val
            attributes[:companyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:companyUri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        # @deprecated Use {FolderAttributes#version} instead.
        def revision
          attributes[:version]
        end

        # @deprecated Use {FolderAttributes#version} instead.
        def revision=(val)
          attributes[:version] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def component_content
          attributes[:componentContent]
        end

        def component_content=(val)
          attributes[:componentContent] = val
        end

      end
    end

  end
end
