require 'uu/os/rest/dto'

module UU
  module OS
    
      module Macro

        class MacroExec < UU::OS::REST::DTO

          # Code of use case be execute (use case code is translated to a particular macro based
          # on main entity using use case registry).
          attr_accessor :use_case_code

          # Flag determining if the invoker wants the command to automatically wait for macro completion
          # (including all subtasks) or will handle the waiting itself (using the returned UESURI of macro
          # process). Default value: do not wait automatically.
          attr_accessor :wait_for_finish

          # Macro data (parameters). The expected value is an instance of Hash, JSON representing Hash or
          # UESURI of text property containing JSON representing Hash.
          attr_accessor :data

          # Additional macro options (may be an instance of Hash, JSON representing Hash or UESURI of
          # text property containing JSON representing Hash).
          attr_accessor :options

          def use_case_code 
            attributes[:useCaseCode]
          end

          def use_case_code=(val) 
            attributes[:useCaseCode] = val
          end

          def wait_for_finish 
            attributes[:waitForFinish]
          end

          def wait_for_finish=(val) 
            attributes[:waitForFinish] = val
          end

          def data 
            attributes[:data]
          end

          def data=(val) 
            attributes[:data] = val
          end

          def options 
            attributes[:options]
          end

          def options=(val) 
            attributes[:options] = val
          end

          def to_hash 
            hash = super()
            # We have to send data and options as JSON.
            # (Server cannot parse Object representing Map)
            if hash[:data].kind_of?Hash
              hash[:data] = hash[:data].to_json
            end
            if hash[:options].kind_of?Hash
              hash[:options] = hash[:options].to_json
            end
            hash
          end

        end

      end
  end
end
