require 'uu/os/qos/qos_handler'
require 'uu/os/rest'
require 'uu/os/uesuri'
require 'uu/os/meta_use_case_realization/meta_use_case_realization_copy'
require 'uu/os/meta_use_case_realization/meta_use_case_realization_attributes'
require 'uu/os/meta_use_case_realization/meta_use_case_realization_set_attributes'



module UU
  module OS
    # Meta Use Case Realization service.
    # @deprecated Use {UU::OS::MetaVisualUseCase} instead.
    module MetaUseCaseRealization
      extend self

      # Service path
      PATH = '/uu/os/MetaUseCaseRealization'

      # Copy a meta use case realization. The command creates a new meta use case realization
      # according to specified source meta use case realization in a specified location.
      # At the very least location meta use case realization and name must be specified
      # in {MetaUseCaseRealizationCopy} DTO. Competent role for the new meta use case realization
      # copy will be selected as the most suitable according to specified container and
      # role(executive/authorized role with connected interface), or can be also specified
      # in {MetaUseCaseRealizationCopy} DTO.
      # 
      # @param [String, UU::OS::UESURI] source_meta_artifact_uri UESURI of the meta use case realization which will be copied
      # @param [MetaUseCaseRealizationCopy] meta_use_case_realization DTO containing attributes of the new meta use case realization copy
      #
      # @return [UU::OS::UESURI] UESURI of the new meta use case realization 
      def copy(source_meta_artifact_uri, meta_use_case_realization = nil)
        svc = UU::OS::REST::RemoteClient.new(MetaUseCaseRealization)
        payload = UU::OS::MetaUseCaseRealization::MetaUseCaseRealizationCopy.new(meta_use_case_realization).to_json

        UU::OS::QoS::QoSHandler.auto_retry do
          res = svc.post('copy', source_meta_artifact_uri, payload)
          return UU::OS::UESURI.new(res)
        end
      end

      # This command returns attributes representing the meta use case realization specified by the meta_use_case_realization_uri
      # parameter.
      # 
      # @param [String, UU::OS::UESURI] meta_use_case_realization_uri UESURI of the MUCR for which we'll fetch its attributes
      #
      # @return [MetaUseCaseRealizationAttributes] DTO containing the MUCR attributes 
      def get_attributes(meta_use_case_realization_uri)
        svc = UU::OS::REST::RemoteClient.new(MetaUseCaseRealization)
        UU::OS::QoS::QoSHandler.auto_retry do
          res = svc.get('getAttributes', meta_use_case_realization_uri)
          return MetaUseCaseRealization::MetaUseCaseRealizationAttributes.new(res)
        end
      end

      # The command sets attributes on specified meta use case realization according to useCaseUri.
      # 
      # @param [String, UU::OS::UESURI] meta_use_case_realization_uri UESURI of the MUCR for which we'll set new attributes
      # @param [MetaUseCaseRealizationSetAttributes] DTO containing new attributes
      #
      # @return [UU::OS::UESURI] UESURI of the MUCR after attributes change
      def set_attributes(meta_use_case_realization_uri, meta_use_case_realization = nil)
        svc = UU::OS::REST::RemoteClient.new(MetaUseCaseRealization)
        payload = UU::OS::MetaUseCaseRealization::MetaUseCaseRealizationSetAttributes.new(meta_use_case_realization).to_json

        UU::OS::QoS::QoSHandler.auto_retry do
          res = svc.post('setAttributes', meta_use_case_realization_uri, payload)
          return UU::OS::UESURI.new(res)
        end
      end

    end
  end
end
