require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module PropertyTemplate
      class PropertyTemplateAttributes < UU::OS::REST::DTO

        # UESURI of the property template.
        attr_accessor :uri

        # Name of the property template.
        attr_accessor :name

        # Code of the property template.
        attr_accessor :code

        # Description of the property template.
        attr_accessor :description

        # Type of the property template.
        attr_accessor :type

        # UESURI of the property collection template. If the property template is in the root collection template, UESURI of the meta-artifact is returned.
        attr_accessor :collection_template_uri

        # The value of the property template. If property template is of type BINARY or IMAGE - null is returned.
        attr_accessor :value
        
        # UESURI of the entity type of the property template.
        attr_accessor :entity_type_uri

        # Creation time of the property template.
        attr_accessor :creation_time

        # Modification time of the property template.
        attr_accessor :modification_time

        # Version of the property template.
        attr_accessor :version

        # Value restriction if present: string with UESURI of property group when enum, String pattern when regular expression, String query when
        # meta-artifacts and organizational units.
        attr_accessor :value_restriction
        
        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def collection_template_uri
          attributes[:collectionTemplateUri]
        end

        def collection_template_uri=(val)
          if val
            attributes[:collectionTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:collectionTemplateUri] = nil
          end
        end

        def value
          attributes[:value]
        end

        def value=(val)
          # Value is not transformed, because it is Object. Only chance to guess
          # proper value type is either from type or template_uri attributes. But
          # these attributes are not available on plain get_value command.
          # Therefore we are not transforming data here to maintain API consistency.
          # Caller has to know which type he expects and parse value manually.
          attributes[:value] = val
        end
        
        def entity_type_uri 
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val) 
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def value_restriction
          attributes[:valueRestriction]
        end

        def value_restriction=(val)
          attributes[:valueRestriction] = val
        end

      end

    end
  end
end
