require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Role
      class RoleSetAttributes < UU::OS::REST::DTO

        # @see Role#set_attributes
        attr_accessor :name

        # @see Role#set_attributes
        attr_accessor :code

        # @see Role#set_attributes
        attr_accessor :description

        # @see Role#set_attributes
        attr_accessor :security_level

        # @see Role#set_attributes
        attr_accessor :searchable_in_territory

        # @deprecated This attribute has been deprecated and will not be supported in the future.
        attr_accessor :searchable_across_territories

        # @deprecated This attribute has been deprecated. The visual use case for displaying territories and organizational units, which this attribute was used for, is no longer supported.
        attr_accessor :territory_switch_visible

        # @see Role#set_attributes
        attr_accessor :icon_uri

        # @deprecated All From OU will not be used in the new authorization (v4).
        attr_accessor :grant_all_from_organizational_unit

        # @see Role#set_attributes
        attr_accessor :component_content
        
        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def searchable_in_territory
          attributes[:searchableInTerritory]
        end

        def searchable_in_territory=(val)
          attributes[:searchableInTerritory] = val
        end

        # @deprecated This attribute has been deprecated and will not be supported in the future.
        def searchable_across_territories
          attributes[:searchableAcrossTerritories]
        end

        # @deprecated This attribute has been deprecated and will not be supported in the future.
        def searchable_across_territories=(val)
          attributes[:searchableAcrossTerritories] = val
        end

        # @deprecated This attribute has been deprecated. The visual use case for displaying territories and organizational units, which this attribute was used for, is no longer supported.
        def territory_switch_visible
          attributes[:territorySwitchVisible]
        end

        # @deprecated This attribute has been deprecated. The visual use case for displaying territories and organizational units, which this attribute was used for, is no longer supported.
        def territory_switch_visible=(val)
          attributes[:territorySwitchVisible] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        # @deprecated All From OU will not be used in the new authorization (v4).
        def grant_all_from_organizational_unit
          attributes[:grantAllFromOrganizationalUnit]
        end

        # @deprecated All From OU will not be used in the new authorization (v4).
        def grant_all_from_organizational_unit=(val)
          attributes[:grantAllFromOrganizationalUnit] = val
        end

        def component_content
          attributes[:componentContent]
        end

        def component_content=(val)
          attributes[:componentContent] = val
        end

      end
    end

  end
end
