require 'uu/os/rest/dto'
require 'uu/os/env/version_strategy'


module UU
  module OS
    module Sheet
      class SheetCheckIn < UU::OS::REST::DTO

        # The new name of the sheet. When null is set, the name is not modified. The name must
        # be unique in a given artifact, otherwise the create commandfails.
        attr_accessor :name

        # The new code of the sheet. When null is set, the code is not modified. The code must
        # be unique in a given artifact, otherwise the checkIn commandfails.
        attr_accessor :code

        # The new description of the sheet. When null is set, the description is not modified.
        attr_accessor :description

        # The content of the sheet.
        attr_accessor :content

        # The version label of the new sheet version. When null is set, it is left empty.
        attr_accessor :version_label

        # Specifies how to work with versions. When null is set, the CREATE_NEW_VERSION
        # strategy is used, therefore the new version is created and data arepublished (the
        # sheet is unlocked).
        attr_accessor :version_strategy
        
        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end

        def content 
          attributes[:content]
        end

        def content=(val) 
          attributes[:content] = val
        end

        def version_label 
          attributes[:versionLabel]
        end

        def version_label=(val) 
          attributes[:versionLabel] = val
        end

        def version_strategy 
          attributes[:versionStrategy]
        end

        def version_strategy=(val) 
          attributes[:versionStrategy] = val
        end

        def to_hash 
          hash = super()
          if hash[:versionStrategy].nil?
            hash[:versionStrategy] = UU::OS::Env::VersionStrategy::OVERWRITE_VERSION
          end
          hash
        end

      end
    end

  end
end
